function MemoryHog()
{
	this.currentList = '';
	this.currentHog = '';
	this.currentHogSize = '';
	this.currentScale = 100;
	this.defaultTextSize = 0;
	this.defaultWidth = 0;
	this.defaultHeight = 0;
}
// column where the Images actually start to be listed, zero-based
MemoryHog.prototype.infoStarts = 3;	
// info for current state of the hog
MemoryHog.prototype.nameColumnStart = 0;
MemoryHog.prototype.nameColumnEnd = 0
MemoryHog.prototype.memColumnStart = 0;
MemoryHog.prototype.memColumnEnd = 0;

// return true when we're done, so we can then open up the window
MemoryHog.prototype.init = function()
{
	this.defaultTextSize = preferences.textSize.value;
	this.getColumns();
	return this.getHog(false);
}
// Returns a string w/ the Hog process and mem in MB. 
//  Also updates this info in this.currentHog and this.currentHogSize
MemoryHog.prototype.getHog = function(bUpdate)
{
	// we can run this w/o running the tasklist command.  Only useful on init, once we've already
	// run getColumns, which already sets up currentList
	if(bUpdate == null)
		bUpdate = true;
	if(bUpdate)
		this.currentList = runCommand("tasklist").split("\n");
	// set up arrays w/ the names of the tasks and the memory they're taking
	items = Array();
	memItems = Array();
	for(i=this.infoStarts; i<this.currentList.length; ++i)
	{
		items.push( this.currentList[i].substr(this.nameColumnStart, this.nameColumnEnd) );
		memItems.push( this.currentList[i].substr(this.memColumnStart, this.memColumnEnd) );
	}
	this.trimMemValues(memItems);	// trim off spaces and 'K' from the mem values
	// find which item is biggest by it's mem val.
	maxItem = 0;
	biggest = -1;
	for(i=0; i<memItems.length; ++i)
	{
		val = Number(memItems[i]);
		if( val > maxItem )
		{
			maxItem = val;
			biggest = i;
		}
	}
	// set currentHog / currentHogSize and return
	this.currentHog = this.trimNameValue(items[biggest]);
	this.currentHogSize = this.convertKtoMbytes(memItems[biggest]);
	return this.currentHog + " (" + this.currentHogSize + " MB)";
}
// gets rid of spaces in front and back of the name
MemoryHog.prototype.trimNameValue = function(theName)
{
	pattern = /(^\s+)|(\s+$)/;
	return theName.replace(pattern, '');
}
// gets rid of spaces and 'K' from mem value, stripes the commas, which JS can't handle in Numbers
// The String "     3,242 K  " would return as "3242"
MemoryHog.prototype.trimMemValues = function(theArray)
{
	pattern = /(\d+,*)+/ ;
	for(i=0; i<theArray.length; ++i)
	{
		val = theArray[i].match(pattern)[0];
		theArray[i] = val.replace(/,/g, '');
	}
}

MemoryHog.prototype.convertKtoMbytes = function(val)
{
	return Math.round( val / 1024 );
}

// rather than rely upon fixed substring value, we find out exactly which columns from tasklist are 
// the name and memory values.  These ARE subject to change (at least substring position of) depending on OS.
// tasklist output separates headings from values with a series of "=" characters. 
	// ie: (From WinXP Pro 32-bit)
	// Image Name                   PID Session Name     Session#    Mem Usage
	// ========================= ====== ================ ======== ============
	// Konfabulator.exe            3932                         0      2,980 K
	// etc.. 
MemoryHog.prototype.getColumns = function()
{
	// Run tasklist, find start index of "Image Name" and "Mem Usage" Headings
	this.currentList = runCommand("tasklist").split("\n");
	nameStart = this.currentList[1].match(/Image Name/).index;
	memStart = this.currentList[1].match(/Mem Usage/).index;
	// Make an array for the indices, to which we'll add the substr index after each space
	// also, the first and last "=" char.  We'll search between these for the nameStart & memStart.
	indices = Array();
	indices.push(0);
	str = this.currentList[2];	// [2] is the "===="'s line
	while(str.length > 0)
	{
		val = str.match(/\s/);	// match whitespace
		if(val)
		{
			ind = val.index+1;
				// add index we just found to last, to keep values consistent w/ whole string.
			indices.push(indices[indices.length-1] + ind);	
				// remove everything before the index we added to search rest of string.
			str = str.substr(ind);
		}
		else 
			str = "";
	}
	indices.push(this.currentList[2].length-1);
	// search w/in indices array find which indexes the name and mem headers fall within.
	for(i=0; i<indices.length-1; ++i)
	{
		if( nameStart >= indices[i] && nameStart <= indices[i+1] )
		{
			this.nameColumnStart = indices[i];
			this.nameColumnEnd = indices[i+1] -1;
		}
		else if( memStart >= indices[i] && memStart <= indices[i+1] )
		{
			this.memColumnStart = indices[i];
			this.memColumnEnd = indices[i+1] -1;
		}
	}
}